@@ -1,4 +1,3 @@
-import jinja2
 from django.template.loader import render_to_string
 from jinja2 import Environment, PackageLoader, select_autoescape
 
@@ -42,3 +41,25 @@ class SerializerTestGenerator(object):
         rendered = self.template.render(serializer_info)
         with open(filename, 'w', encoding='utf-8') as file:
             file.write(rendered)
+
+
+class GenericTemplateWriter(object):
+
+    def __init__(self, template_name, **kwargs):
+        trim_blocks = kwargs.get('trim_blocks', False)
+        lstrip_blocks = kwargs.get('lstrip_blocks', False)
+        self.env = Environment(
+            loader=PackageLoader('django_test_tools', 'templates'),
+            autoescape=select_autoescape(['html', ],),
+            trim_blocks=trim_blocks,
+            lstrip_blocks=lstrip_blocks
+        )
+        self.env.filters['to_snake_case'] = to_snake_case
+
+        self.template_name = 'django_test_tools/{}'.format(template_name)
+        self.template = self.env.get_template(self.template_name)
+
+    def write(self, template_data, filename):
+        rendered = self.template.render(template_data)
+        with open(filename, 'w', encoding='utf-8') as file:
+            file.write(rendered)
